@@ -1,20 +1,20 @@
 # -*- coding: utf-8 -*-
-from notify.settings import (
+from notify.providers.mail import ProviderEmail
+from .settings import (
     SENDGRID_USER,
     SENDGRID_KEY
 )
-from notify.providers.abstract import ProviderEmail
-
 
 class Sendgrid(ProviderEmail):
     """
     Sendgrid.
-    
+
     Sendgrid SMTP Client.
+    TODO: migrate to API.
     """
     provider = 'sendgrid'
     blocking: bool = False
-    
+
 
     def __init__(self, username: str = None, password: str = None, **kwargs):
         """
@@ -22,8 +22,6 @@ class Sendgrid(ProviderEmail):
         """
         self._attachments: list = []
         self.force_tls: bool = True
-        self.username = None
-        self.password = None
 
         super(Sendgrid, self).__init__(**kwargs)
 
@@ -31,14 +29,12 @@ class Sendgrid(ProviderEmail):
         self._host = 'smtp.sendgrid.net'
         self._port = 587
         # connection related settings
-        if username:
-            self.username = username
-        else:
+        self.username = username
+        if not self.username:
             self.username = SENDGRID_USER
-        
-        if password:
-            self.password = password
-        else:
+
+        self.password = password
+        if not self.password:
             self.password = SENDGRID_KEY
 
         try:
@@ -48,4 +44,4 @@ class Sendgrid(ProviderEmail):
             else:
                 self.actor = self.username
         except KeyError:
-            self.actor = self.username
\ No newline at end of file
+            self.actor = self.username
